searchData={"items":[{"type":"module","title":"FeatureSupervisor","doc":"A small wrapper for `Supervisor` that dynamically starts/terminates children based on feature flags.","ref":"FeatureSupervisor.html"},{"type":"module","title":"Example - FeatureSupervisor","doc":"defmodule MyApp.Application do\n      use Application\n\n      @mix_env Mix.env()\n\n      def start(_type, _args) do\n        children = [\n          # a regular child\n          Child1,\n          # supposed to be disabled in tests\n          FeatureSupervisor.child_spec(Child2, enabled?: @mix_env != :test),\n          # supposed to run only when the feature is enabled\n          FeatureSupervisor.child_spec({Child3, name: Child3},\n            enabled?: &feature_enabled?/1,\n            feature_id: \"my-feature\"\n          )\n        ]\n\n        FeatureSupervisor.start_link(children, strategy: :one_for_one, sync_interval: 1000)\n      end\n\n      defp feature_enabled?(spec) do\n        MyApp.Features.enabled?(spec.feature_id)\n      end\n    end","ref":"FeatureSupervisor.html#module-example"},{"type":"function","title":"FeatureSupervisor.child_spec/2","doc":"Same as `Supervisor.child_spec/2` but allows any key in the overrides.","ref":"FeatureSupervisor.html#child_spec/2"},{"type":"function","title":"FeatureSupervisor.start_link/2","doc":"Wraps the `Supervisor.start_link/2` function.\n\nChildren will be split into two groups:\n\n* \"static\" - those without the `:enabled?` field or with `enabled?: true`\n* \"dynamic\" - those with the `:enabled?` field set to a function\n\nChildren with `enabled?: false` will be excluded.\n\n\"static\" children will be started as normal.\n\n\"dynamic\" children (if any) will be started separately via `Supervisor.start_child/2`.\n\nIf a \"dynamic\" child is expected to be started/terminated later via a feature flag\nyou should provide the `sync_interval` option. The child's `:restart` option must be set to `:permanent`.","ref":"FeatureSupervisor.html#start_link/2"},{"type":"type","title":"FeatureSupervisor.child/0","doc":"","ref":"FeatureSupervisor.html#t:child/0"},{"type":"type","title":"FeatureSupervisor.option/0","doc":"","ref":"FeatureSupervisor.html#t:option/0"},{"type":"extras","title":"FeatureSupervisor","doc":"# FeatureSupervisor\n\n[![CI](https://github.com/nmbrone/feature_supervisor/actions/workflows/ci.yml/badge.svg)](https://github.com/nmbrone/feature_supervisor/actions/workflows/ci.yml)\n\nA small wrapper for `Supervisor` that dynamically starts/terminates children based on feature flags.","ref":"readme.html"},{"type":"extras","title":"Installation - FeatureSupervisor","doc":"The package can be installed by adding `feature_supervisor` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:feature_supervisor, \"~> 0.1.0\"} # {x-release-please-version}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"How to use - FeatureSupervisor","doc":"`FeatureSupervisor` should be used the same way you would use `Supervisor`.\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @mix_env Mix.env()\n\n  def start(_type, _args) do\n    children = [\n      # a regular child\n      Child1,\n      # supposed to be disabled in tests\n      FeatureSupervisor.child_spec(Child2, enabled?: @mix_env != :test),\n      # supposed to run only when the feature is enabled\n      FeatureSupervisor.child_spec({Child3, name: Child3},\n        enabled?: &feature_enabled?/1,\n        feature_id: \"my-feature\"\n      )\n    ]\n\n    FeatureSupervisor.start_link(children, strategy: :one_for_one, sync_interval: 1000)\n  end\n\n  defp feature_enabled?(spec) do\n    MyApp.Features.enabled?(spec.feature_id)\n  end\nend\n```","ref":"readme.html#how-to-use"}],"content_type":"text/markdown"}